summaryrefslogtreecommitdiff
path: root/lib/gnutls_x509.c
diff options
context:
space:
mode:
authorNikos Mavrogiannopoulos <nmav@gnutls.org>2002-02-03 20:19:18 +0000
committerNikos Mavrogiannopoulos <nmav@gnutls.org>2002-02-03 20:19:18 +0000
commit67a69b918f243b212f3d0dab400d2c97ba607bdf (patch)
treeb0fa652a3595e579fe0c07b23425a138d38bca87 /lib/gnutls_x509.c
parent9a713d88742ec178ef1a761f23fb1ad3d5ae0d8f (diff)
downloadgnutls-67a69b918f243b212f3d0dab400d2c97ba607bdf.tar.gz
renamed the gnutls_dn structure to gnutls_x509_dn
Diffstat (limited to 'lib/gnutls_x509.c')
-rw-r--r--lib/gnutls_x509.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/lib/gnutls_x509.c b/lib/gnutls_x509.c
index 798210a1a1..0f7a191f8f 100644
--- a/lib/gnutls_x509.c
+++ b/lib/gnutls_x509.c
@@ -318,11 +318,11 @@ int _gnutls_x509_get_version(node_asn * c2, char *root)
* @rdn: a pointer to a structure to hold the name
*
* This function will return the name of the given RDN sequence.
* The name will be returned as a gnutls_dn structure.
* Returns a negative error code in case of an error.
*
**/
-int gnutls_x509_extract_dn(const gnutls_datum * idn, gnutls_dn * rdn)
+int gnutls_x509_extract_dn(const gnutls_datum * idn, gnutls_x509_dn * rdn)
{
node_asn *dn;
int result;
@@ -360,19 +360,19 @@ int gnutls_x509_extract_dn(const gnutls_datum * idn, gnutls_dn * rdn)
* @cert: should contain an X.509 DER encoded certificate
* @ret: a pointer to a structure to hold the peer's name
*
* This function will return the name of the certificate holder. The name is gnutls_dn structure and
* is a obtained by the peer's certificate. If the certificate send by the
* peer is invalid, or in any other failure this function returns error.
* Returns a negative error code in case of an error.
*
**/
int gnutls_x509_extract_certificate_dn(const gnutls_datum * cert,
- gnutls_dn * ret)
+ gnutls_x509_dn * ret)
{
node_asn *c2;
int result;
- memset(ret, 0, sizeof(gnutls_dn));
+ memset(ret, 0, sizeof(gnutls_x509_dn));
if (asn1_create_structure
(_gnutls_get_pkix(), "PKIX1Implicit88.Certificate", &c2,
@@ -412,19 +412,19 @@ int gnutls_x509_extract_certificate_dn(const gnutls_datum * cert,
* @cert: should contain an X.509 DER encoded certificate
* @ret: a pointer to a structure to hold the issuer's name
*
* This function will return the name of the issuer stated in the certificate. The name is a gnutls_dn structure and
* is a obtained by the peer's certificate. If the certificate send by the
* peer is invalid, or in any other failure this function returns error.
* Returns a negative error code in case of an error.
*
**/
int gnutls_x509_extract_certificate_issuer_dn(const gnutls_datum * cert,
- gnutls_dn * ret)
+ gnutls_x509_dn * ret)
{
node_asn *c2;
int result;
- memset(ret, 0, sizeof(gnutls_dn));
+ memset(ret, 0, sizeof(gnutls_x509_dn));
if (asn1_create_structure
(_gnutls_get_pkix(), "PKIX1Implicit88.Certificate", &c2,
@@ -318,11 +318,11 @@ int _gnutls_x509_get_version(node_asn * c2, char *root)
*
* This function will return the name of the given RDN sequence.
- * The name will be returned as a gnutls_dn structure.
+ * The name will be returned as a gnutls_x509_dn structure.
* Returns a negative error code in case of an error.
*
@@ -360,19 +360,19 @@ int gnutls_x509_extract_dn(const gnutls_datum * idn, gnutls_dn * rdn)
* @ret: a pointer to a structure to hold the peer's name
*
- * This function will return the name of the certificate holder. The name is gnutls_dn structure and
+ * This function will return the name of the certificate holder. The name is gnutls_x509_dn structure and
* is a obtained by the peer's certificate. If the certificate send by the
* peer is invalid, or in any other failure this function returns error.
@@ -412,19 +412,19 @@ int gnutls_x509_extract_certificate_dn(const gnutls_datum * cert,
* @ret: a pointer to a structure to hold the issuer's name
*
- * This function will return the name of the issuer stated in the certificate. The name is a gnutls_dn structure and
+ * This function will return the name of the issuer stated in the certificate. The name is a gnutls_x509_dn structure and
* is a obtained by the peer's certificate. If the certificate send by the
* peer is invalid, or in any other failure this function returns error.